Documentation
¶
Overview ¶
Package target resolves and dispatches built-in target adapters.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Capabilities ¶
func Capabilities(adapter Adapter) []model.CapabilityRule
Capabilities returns an adapter's capability rules.
func Render ¶
func Render(adapter Adapter, input model.TargetRenderInput) (model.TargetPlan, []model.Diagnostic)
Render renders one explicit target request through adapter after validation.
Types ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
Package antigravity renders normalized packages as Antigravity CLI plugins.
|
Package antigravity renders normalized packages as Antigravity CLI plugins. |
|
Package claude renders normalized packages for Claude Code.
|
Package claude renders normalized packages for Claude Code. |
|
Package codex renders normalized packages as Codex plugins.
|
Package codex renders normalized packages as Codex plugins. |
|
Package copilot renders normalized packages for GitHub Copilot.
|
Package copilot renders normalized packages for GitHub Copilot. |
|
Package cursor renders normalized packages as Cursor plugins.
|
Package cursor renders normalized packages as Cursor plugins. |
|
Package grok renders normalized packages for Grok Build.
|
Package grok renders normalized packages for Grok Build. |
|
Package hookdecision renders a canonical decision-hook process wrapper into vendor protocols.
|
Package hookdecision renders a canonical decision-hook process wrapper into vendor protocols. |
|
Package marketplace builds target-neutral marketplace catalog entries.
|
Package marketplace builds target-neutral marketplace catalog entries. |
|
Package packageoutput renders installable target package roots.
|
Package packageoutput renders installable target package roots. |
|
Package pi renders normalized packages for Pi.
|
Package pi renders normalized packages for Pi. |
|
Package plugin renders the common single-package native plugin skill subset.
|
Package plugin renders the common single-package native plugin skill subset. |
|
Package skills renders the common native skill subset for target adapters.
|
Package skills renders the common native skill subset for target adapters. |
Click to show internal directories.
Click to hide internal directories.